Add Media_Type_Document in FileColumns

Bug: 138173113
Test: m -j
Change-Id: Ia318e2ee4161aed1d670c70359a2b2e5f5632166
diff --git a/apex/framework/java/android/provider/MediaStore.java b/apex/framework/java/android/provider/MediaStore.java
index 41eb152..97c9578 100644
--- a/apex/framework/java/android/provider/MediaStore.java
+++ b/apex/framework/java/android/provider/MediaStore.java
@@ -1498,7 +1498,7 @@
             public static final String TITLE = "title";
 
             /**
              * The media type (audio, video, image or playlist)
              * of the file, or 0 for not a media file
              */
             @Column(Cursor.FIELD_TYPE_INTEGER)
@@ -1506,7 +1506,7 @@
 
             /**
              * Constant for the {@link #MEDIA_TYPE} column indicating that file
              * is not an audio, image, video, playlist, or subtitles file.
              */
             public static final int MEDIA_TYPE_NONE = 0;
 
@@ -1539,6 +1539,11 @@
              * is a subtitles or lyrics file.
              */
             public static final int MEDIA_TYPE_SUBTITLE = 5;
+
+            /**
+             * Constant for the {@link #MEDIA_TYPE} column indicating that file is a document file.
+             */
+            public static final int MEDIA_TYPE_DOCUMENT = 6;
         }
     }
@@ -1498,7 +1498,7 @@
 
             /**
-             * The media type (audio, video, image or playlist)
+             * The media type (audio, video, image, document, playlist or subtitle)
              * of the file, or 0 for not a media file
              */
@@ -1506,7 +1506,7 @@
             /**
              * Constant for the {@link #MEDIA_TYPE} column indicating that file
-             * is not an audio, image, video, playlist, or subtitles file.
+             * is not an audio, image, video, document, playlist, or subtitles file.
              */
             public static final int MEDIA_TYPE_NONE = 0;